/*
 * The contents of this file are subject to the Mozilla Public License 
 * Version 1.1 (the "License"); you may not use this file except in 
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" 
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific language governing rights and limitations 
 * under the License.
 * 
 * The Original Code is the NRL Parser, released 28 April 2006, 
 * Copyright (c) Christian Nentwich. The Initial Developer of the 
 * Original Code is Christian Nentwich. Portions created by contributors 
 * identified in the NOTICES file are Copyright (c) the contributors. 
 * All Rights Reserved. 
 */
package net.sourceforge.nrl.parser.ast.impl;

import net.sourceforge.nrl.parser.NRLParserTestCase;
import net.sourceforge.nrl.parser.ast.IRuleSetDeclaration;
import net.sourceforge.nrl.parser.ast.constraints.IBinaryPredicate;
import net.sourceforge.nrl.parser.ast.constraints.impl.ModelReferenceImpl;
import net.sourceforge.nrl.parser.ast.impl.NRLActionParser;
import net.sourceforge.nrl.parser.ast.impl.RuleSetDeclarationImpl;

/**
 * Unit tests for rule set class.
 * 
 * @author Christian Nentwich
 */
public class RuleSetDeclarationImplTest extends NRLParserTestCase {

	public void testParse() throws Exception {
		// Parse without precondition
		NRLActionParser parser = getParserFor("Rule set \"test\"");
		
		IRuleSetDeclaration set = (IRuleSetDeclaration) parser.ruleSetDeclaration().getTree();
		assertNull(set.getPreconditionConstraint());
		assertNull(set.getPreconditionContext());
		assertEquals("test", set.getId());

		// Now with
		parser = getParserFor("Rule set \"test\" Applies to Foo where ab = 'c'");
		set = (IRuleSetDeclaration) parser.ruleSetDeclaration().getTree();
		
		// Context must still be null - because not resolved yet.
		assertNull(set.getPreconditionContext());
		assertEquals("test", set.getId());
		assertTrue(set.getPreconditionConstraint() instanceof IBinaryPredicate);
		assertTrue(((ModelReferenceImpl) ((RuleSetDeclarationImpl) set)
				.getModelReference()).getOriginalString().equals("Foo"));
	}
}
