package net.sourceforge.nrl.parser.model.xsd;

import static net.sourceforge.nrl.parser.model.xsd.IXSDUserData.*;

import java.io.File;

import junit.framework.TestCase;
import net.sourceforge.nrl.parser.model.IAttribute;
import net.sourceforge.nrl.parser.model.IClassifier;
import net.sourceforge.nrl.parser.model.IPackage;

import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.xsd.util.XSDResourceFactoryImpl;

/** Test meta-data added to XSDAttributes */
public class MetaDataTest extends TestCase {

	private static boolean isInitialised = false;

	private static IPackage model = null;

	public void setUp() throws Exception {
		if (!isInitialised) {
			Resource.Factory.Registry.INSTANCE.getExtensionToFactoryMap().put("xsd",
					new XSDResourceFactoryImpl());
			isInitialised = true;

			XSDModelLoader loader = new XSDModelLoader();
			model = loader.load(new File("testdata/schema/metadata.xsd"));

			for (String warning : loader.getWarnings()) {
				System.err.println(warning);
			}
		}
	}

	public void testXSDAttributeKind() throws Exception {
		IClassifier parent = (IClassifier) model.getElementByName("aTypeOne", true);
		IAttribute attribute = parent.getAttributeByName("aTypeOneAttributeOne", false);
		assertEquals(XSD_ATTRIBUTE_KIND, attribute
				.getUserData(ATTRIBUTE_KIND));
	}

	public void testtestXSDElementKind() throws Exception {
		IClassifier parent = (IClassifier) model.getElementByName("aTypeOne", true);
		IAttribute attribute = parent.getAttributeByName("aTypeOneElementOne", false);
		assertEquals(XSD_ELEMENT_KIND, attribute
				.getUserData(ATTRIBUTE_KIND));

	}

	public void testAttributeNamespaceSet() throws Exception {
		IClassifier parent = (IClassifier) model.getElementByName("aTypeOne", true);
		IAttribute attribute = parent.getAttributeByName("aTypeOneAttributeOne", false);
		assertEquals("http://www.modeltwozero.com/test/a", attribute
				.getUserData(NAMESPACE));
	}

	public void testElementNamespaceSet() throws Exception {
		IClassifier parent = (IClassifier) model.getElementByName("aTypeOne", true);
		IAttribute attribute1 = parent.getAttributeByName("aTypeOneElementOne", false);
		assertEquals("http://www.modeltwozero.com/test/a", attribute1
				.getUserData(NAMESPACE));
		
		IAttribute attribute2 = parent.getAttributeByName("bElementOne", false);
		assertEquals("http://www.modeltwozero.com/test/b", attribute2
				.getUserData(NAMESPACE));
	}

	public void testClassifierNamespaceSet() throws Exception {
		IClassifier aTypeOne = (IClassifier) model.getElementByName("aTypeOne", true);
		assertEquals("http://www.modeltwozero.com/test/a", aTypeOne.getUserData(NAMESPACE));
		
		IClassifier bTypeOne = (IClassifier) model.getElementByName("bTypeOne", true);
		assertEquals("http://www.modeltwozero.com/test/b", bTypeOne.getUserData(NAMESPACE));
	}

	public void testElementWithAnonymousType() throws Exception {
		IClassifier anonymousType = (IClassifier) model.getElementByName("AnonymousElement", true);
		assertEquals("http://www.modeltwozero.com/test/a", anonymousType.getUserData(NAMESPACE));
		
		IClassifier parent = (IClassifier) model.getElementByName("aTypeOne", true);
		IAttribute anonymousElement = parent.getAttributeByName("anonymousElement", false);
		assertEquals("http://www.modeltwozero.com/test/a", anonymousElement
				.getUserData(NAMESPACE));
	}

}
